@@ -1,5 +1,5 @@
 # Copyright 2005 Duke University
-# Copyright (C) 2012-2015  Red Hat, Inc.
+# Copyright (C) 2012-2016 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -179,7 +179,7 @@ class Output(object):
 
     @property
     def yumdb(self):
-        return self.base.yumdb
+        return self.base._yumdb
 
     def calcColumns(self, data, columns=None, remainder_column=0,
                     total_width=None, indent=''):
@@ -403,6 +403,10 @@ class Output(object):
         """Print a package as a line containing its name."""
         print(ucd(pkg.name))
 
+    def simple_nevra_list(self, pkg):
+        """Print a package as a line containing its NEVRA."""
+        print(ucd(pkg))
+
     def fmtKeyValFill(self, key, val):
         """Return a key value pair in the common two column output
         format.
@@ -551,6 +555,7 @@ class Output(object):
               'list' - simple pkg list
               'info' - similar to rpm -qi output
               'name' - simple name list
+              'nevra' - simple nevra list
         :param highlight_na: a dictionary containing information about
               packages that should be highlighted in the output.  The
               dictionary keys are (name, arch) tuples for the package,
@@ -582,7 +587,7 @@ class Output(object):
             1 = we've errored, exit with error string
 
         """
-        if outputType in ['list', 'info', 'name']:
+        if outputType in ['list', 'info', 'name', 'nevra']:
             thingslisted = 0
             if len(lst) > 0:
                 thingslisted = 1
@@ -606,6 +611,8 @@ class Output(object):
                         self.infoOutput(pkg, highlight=highlight)
                     elif outputType == 'name':
                         self.simple_name_list(pkg)
+                    elif outputType == 'nevra':
+                        self.simple_nevra_list(pkg)
                     else:
                         pass
 
@@ -704,7 +711,7 @@ class Output(object):
         """
         def names(packages):
             return sorted(pkg.name for pkg in packages)
-        print(_('\nGroup: %s') % group.ui_name)
+        print('\n' + _('Group: %s') % group.ui_name)
 
         verbose = self.conf.verbose
         if verbose:
@@ -739,7 +746,7 @@ class Output(object):
     def display_groups_in_environment(self, environment):
         """Output information about the packages in a given environment
 
-        :param environment: a Environment object to output information about
+        :param environment: an Environment object to output information about
         """
         def names(groups):
             return sorted(group.name for group in groups)
@@ -911,18 +918,18 @@ class Output(object):
         out = []
         rows = []
         if diff.new_groups:
-            out.append(_('Marking installed:'))
+            out.append(_('Marking packages as installed by the group:'))
         for grp_id in diff.new_groups:
             pkgs = list(diff.added_packages(grp_id))
             grp_name = comps.group_by_id(grp_id).ui_name
-            rows.extend(_spread_in_columns(4, grp_name, pkgs))
+            rows.extend(_spread_in_columns(4, "@" + grp_name, pkgs))
         if diff.removed_groups:
             assert not rows
-            out.append(_('Marking removed:'))
+            out.append(_('Marking packages as removed by the group:'))
         for grp_id in diff.removed_groups:
             pkgs = list(diff.removed_packages(grp_id))
             grp_name = prst.group(grp_id).ui_name
-            rows.extend(_spread_in_columns(4, grp_name, pkgs))
+            rows.extend(_spread_in_columns(4, "@" + grp_name, pkgs))
 
         if rows:
             col_data = self._col_widths(rows)
@@ -966,6 +973,7 @@ class Output(object):
             hawkey.INSTALL
         }
         skipped_conflicts = []
+        skipped_broken = []
 
         if transaction is None:
             return None
@@ -1026,7 +1034,8 @@ class Output(object):
         # show skipped packages with broken dependencies
         if hawkey.UPGRADE_ALL in self.base._goal.actions:
             lines = []
-            for pkg in sorted(self._skipped_broken_deps(skipped_conflicts)):
+            skipped_broken = self._skipped_broken_deps(skipped_conflicts)
+            for pkg in sorted(skipped_broken):
                 a_wid = _add_line(lines, data, a_wid, pkg, [])
             skip_str = _("Skipping packages with broken dependencies")
             pkglist_lines.append((skip_str, lines))
@@ -1059,7 +1068,7 @@ class Output(object):
                 msg = self.fmtColumns(columns, u" ", u"\n")
                 hibeg, hiend = self._highlight(self.conf.color_update_installed)
                 for obspo in sorted(obsoletes):
-                    appended = _('     replacing  %s%s%s.%s %s\n')
+                    appended = '     ' + _('replacing') + '  %s%s%s.%s %s\n'
                     appended %= (hibeg, obspo.name, hiend, obspo.arch, obspo.evr)
                     msg += appended
                 totalmsg = totalmsg + msg
@@ -1075,7 +1084,8 @@ Transaction Summary
             (_('Install'), len(list_bunch.installed), 0),
             (_('Upgrade'), len(list_bunch.upgraded), 0),
             (_('Remove'), len(list_bunch.erased), 0),
-            (_('Downgrade'), len(list_bunch.downgraded), 0))
+            (_('Downgrade'), len(list_bunch.downgraded), 0),
+            (_('Skip'), len(skipped_conflicts) + len(skipped_broken), 0))
         max_msg_action = 0
         max_msg_count = 0
         max_msg_pkgs = 0
@@ -1332,7 +1342,7 @@ Transaction Summary
         for mtid in sorted(rtids):
             if mtid[0] < last_end:
                 msg = ('Skipping merged transaction %d to %d, as it overlaps')
-                logger.warn(msg, mtid[0], mtid[1])
+                logger.warning(msg, mtid[0], mtid[1])
                 continue # Don't do overlapping
             last_end = mtid[1]
             for num in range(mtid[0], mtid[1] + 1):
@@ -1379,65 +1389,63 @@ Transaction Summary
             1 = we've errored, exit with error string
         """
         tids = self._history_list_transactions(extcmds)
-        if tids is None:
-            return 1, ['Failed history list']
-
-        old_tids = self.history.old(tids)
-        if self.conf.history_list_view == 'users':
-            uids = [1, 2]
-        elif self.conf.history_list_view == 'commands':
-            uids = [1]
-        else:
-            assert self.conf.history_list_view == 'single-user-commands'
-            uids = set()
-            done = 0
-            blanks = 0
-            for old in old_tids:
-                done += 1
-                if old.cmdline is None:
-                    blanks += 1
-                uids.add(old.loginuid)
-
-        fmt = "%s | %s | %s | %s | %s"
-        if len(uids) == 1:
-            name = _("Command line")
-        else:
-            name = _("Login user")
-        print(fmt % (fill_exact_width(_("ID"), 6, 6),
-                     fill_exact_width(name, 24, 24),
-                     fill_exact_width(_("Date and time"), 6, 6),
-                     fill_exact_width(_("Action(s)"), 6, 6),
-                     fill_exact_width(_("Altered"), 6, 6)))
-        print("-" * 79)
-        fmt = "%6u | %s | %-16.16s | %s | %4u"
-
-        for old in old_tids:
-            if len(uids) == 1:
-                name = old.cmdline or ''
+        if tids is not None:
+            old_tids = self.history.old(tids)
+            if self.conf.history_list_view == 'users':
+                uids = [1, 2]
+            elif self.conf.history_list_view == 'commands':
+                uids = [1]
             else:
-                name = self._pwd_ui_username(old.loginuid, 24)
-            tm = time.strftime("%Y-%m-%d %H:%M",
-                               time.localtime(old.beg_timestamp))
-            num, uiacts = self._history_uiactions(old.trans_data)
-            name = fill_exact_width(name, 24, 24)
-            uiacts = fill_exact_width(uiacts, 14, 14)
-            rmark = lmark = ' '
-            if old.return_code is None:
-                rmark = lmark = '*'
-            elif old.return_code:
-                rmark = lmark = '#'
-                # We don't check .errors, because return_code will be non-0
-            elif old.output:
-                rmark = lmark = 'E'
-            elif old.rpmdb_problems:
-                rmark = lmark = 'P'
-            elif old.trans_skip:
-                rmark = lmark = 's'
-            if old.altered_lt_rpmdb:
-                rmark = '<'
-            if old.altered_gt_rpmdb:
-                lmark = '>'
-            print(fmt % (old.tid, name, tm, uiacts, num), "%s%s" % (lmark, rmark))
+                assert self.conf.history_list_view == 'single-user-commands'
+                uids = set()
+                done = 0
+                blanks = 0
+                for old in old_tids:
+                    done += 1
+                    if old.cmdline is None:
+                        blanks += 1
+                    uids.add(old.loginuid)
+
+            fmt = "%s | %s | %s | %s | %s"
+            if len(uids) == 1:
+                name = _("Command line")
+            else:
+                name = _("Login user")
+            print(fmt % (fill_exact_width(_("ID"), 6, 6),
+                        fill_exact_width(name, 24, 24),
+                        fill_exact_width(_("Date and time"), 16, 16),
+                        fill_exact_width(_("Action(s)"), 14, 14),
+                        fill_exact_width(_("Altered"), 7, 7)))
+            print("-" * 79)
+            fmt = "%6u | %s | %-16.16s | %s | %4u"
+
+            for old in old_tids:
+                if len(uids) == 1:
+                    name = old.cmdline or ''
+                else:
+                    name = self._pwd_ui_username(old.loginuid, 24)
+                tm = time.strftime("%Y-%m-%d %H:%M",
+                                time.localtime(old.beg_timestamp))
+                num, uiacts = self._history_uiactions(old.trans_data)
+                name = fill_exact_width(name, 24, 24)
+                uiacts = fill_exact_width(uiacts, 14, 14)
+                rmark = lmark = ' '
+                if old.return_code is None:
+                    rmark = lmark = '*'
+                elif old.return_code:
+                    rmark = lmark = '#'
+                    # We don't check .errors, because return_code will be non-0
+                elif old.output:
+                    rmark = lmark = 'E'
+                elif old.rpmdb_problems:
+                    rmark = lmark = 'P'
+                elif old.trans_skip:
+                    rmark = lmark = 's'
+                if old.altered_lt_rpmdb:
+                    rmark = '<'
+                if old.altered_gt_rpmdb:
+                    lmark = '>'
+                print(fmt % (old.tid, name, tm, uiacts, num), "%s%s" % (lmark, rmark))
 
     def historyInfoCmd(self, extcmds):
         """Output information about a transaction in history
@@ -1866,7 +1874,7 @@ Transaction Summary
                 return 1, ['Failed history addon-info']
 
         if not old:
-            logger.critical(_('No Transaction %s found') % tid)
+            logger.critical(_('No Transaction %s found'), tid)
             return 1, ['Failed history addon-info']
 
         hist_data = old[0]
@@ -2182,6 +2190,9 @@ class CliTransactionDisplay(LoggingTransactionDisplay):
             if ti_done == ti_total:
                 print(" ")
 
+    def filelog(self, package, action):
+        pass
+
     def scriptout(self, msgs):
         """Print messages originating from a package script.
 
