@@ -41,7 +41,16 @@ class UnicodeStream(object):
         if not isinstance(s, str):
             s = (s.decode(self.encoding, 'replace') if dnf.pycomp.PY3 else
                  s.encode(self.encoding, 'replace'))
-        self.stream.write(s)
+        try:
+            self.stream.write(s)
+        except UnicodeEncodeError:
+            s_bytes = s.encode(self.stream.encoding, 'backslashreplace')
+            if hasattr(self.stream, 'buffer'):
+                self.stream.buffer.write(s_bytes)
+            else:
+                s = s_bytes.decode(self.stream.encoding, 'ignore')
+                self.stream.write(s)
+
 
     def __getattr__(self, name):
         return getattr(self.stream, name)
@@ -65,7 +74,7 @@ def _full_ucd_support(encoding):
 
 def _guess_encoding():
     """ Take the best shot at the current system's string encoding. """
-    encoding = locale.getpreferredencoding()
+    encoding = locale.getpreferredencoding(False)
     return 'utf-8' if encoding.startswith("ANSI") else encoding
 
 def setup_locale():
@@ -100,6 +109,7 @@ def setup_stdout():
 
 
 def ucd_input(ucstring):
+    # :api, deprecated in 2.0.0, will be erased when python2 is abandoned
     """ It uses print instead of passing the prompt to raw_input.
 
         raw_input doesn't encode the passed string and the output
@@ -110,6 +120,7 @@ def ucd_input(ucstring):
 
 
 def ucd(obj):
+    # :api, deprecated in 2.0.0, will be erased when python2 is abandoned
     """ Like the builtin unicode() but tries to use a reasonable encoding. """
     if dnf.pycomp.PY3:
         if dnf.pycomp.is_py3bytes(obj):
@@ -277,7 +288,15 @@ def textwrap_fill(text, width=70, initial_indent='', subsequent_indent=''):
 
     return '\n'.join(ret)
 
-# setup translation
-t = dnf.pycomp.gettext.translation('dnf', fallback=True)
-_, P_ = dnf.pycomp.gettext_setup(t)
 
+def translation(name):
+    # :api, deprecated in 2.0.0, will be erased when python2 is abandoned
+    """ Easy gettext translations setup based on given domain name """
+
+    def ucd_wrapper(fnc):
+        return lambda *w: ucd(fnc(*w))
+    t = dnf.pycomp.gettext.translation(name, fallback=True)
+    return map(ucd_wrapper, dnf.pycomp.gettext_setup(t))
+
+# setup translations
+_, P_ = translation("dnf")
