@@ -68,7 +68,7 @@ class Package(hawkey.Package):
 
     @property
     def from_repo(self):
-        yumdb_info = self.base.yumdb.get_package(self) if self.from_system else {}
+        yumdb_info = self.base._yumdb.get_package(self) if self.from_system else {}
         if 'from_repo' in yumdb_info:
             return '@'+yumdb_info.from_repo
         return self.reponame
@@ -167,16 +167,17 @@ class Package(hawkey.Package):
         """
         if self.from_cmdline:
             return self.location
-        if self.baseurl:
-            path = os.path.join(self.baseurl, self.location)
-            if path.startswith("file://"):
-                path = path[7:]
-            return path
         loc = self.location
         if not self.repo.local:
             loc = os.path.basename(loc)
+        elif self.baseurl and self.baseurl.startswith('file://'):
+            return os.path.join(self.baseurl, loc)[7:]
         return os.path.join(self.repo.pkgdir, loc)
 
+    def _is_local_pkg(self):
+        return self.from_cmdline or \
+            (self.repo.local and (not self.baseurl or self.baseurl.startswith('file://')))
+
     # yum compatibility method
     def returnIdSum(self):
         """ Return the chksum type and chksum string how the legacy yum expects
@@ -195,7 +196,7 @@ class Package(hawkey.Package):
         real_sum = dnf.yum.misc.checksum(chksum_type, self.localPkg(),
                                          datasize=self.size)
         if real_sum != chksum:
-            logger.debug('%s: %s check failed: %s vs %s' %
-                         (self, chksum_type, real_sum, chksum))
+            logger.debug('%s: %s check failed: %s vs %s',
+                         self, chksum_type, real_sum, chksum)
             return False
         return True
